==> eiffelstudio-18.11.10.2592.tar: F_code/C9/dt435.c <==
/*
 * Code for class DT_FIXED_OFFSET_ZONED_DATE_TIME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt435.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.make_from_zoned_date */
void F1121_8215 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1546, 0).id);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	F1547_13242(RTCW(tr1), tr2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.time_zone */
EIF_REFERENCE F1121_8216 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.zoned_date */
EIF_REFERENCE F1121_8217 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1107, 0x00).id, 1107, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr2 = F1547_13245(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current);
	F1108_8059(RTCW(tr1), tr2, tr3);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.zoned_time */
EIF_REFERENCE F1121_8218 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1108, 0x00).id, 1108, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr2 = F1547_13246(RTCW(tr2));
	tr3 = *(EIF_REFERENCE *)(Current);
	F1109_8067(RTCW(tr1), tr2, tr3);
	Result = (EIF_REFERENCE) tr1;
	RTLE;
	return Result;
}

void EIF_Minit435 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C9/dt435.c <==
/*
 * Code for class DT_FIXED_OFFSET_ZONED_DATE_TIME
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt435.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.make_from_zoned_date */
void F1121_8246 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	tr1 = RTLNSMART(eif_new_type(1553, 1).id);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	F1554_13283(RTCW(tr1), tr2);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.zoned_date */
EIF_REFERENCE F1121_8248 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1108, 0x01).id, 1108, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1554_13286(RTCW(tr1));
	tr2 = *(EIF_REFERENCE *)(Current);
	F1109_8098(RTCW(Result), tr1, tr2);
	RTLE;
	return Result;
}

/* {DT_FIXED_OFFSET_ZONED_DATE_TIME}.zoned_time */
EIF_REFERENCE F1121_8249 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	Result = RTLNS(eif_new_type(1107, 0x01).id, 1107, _OBJSIZ_2_0_0_0_0_0_0_0_);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	tr1 = F1554_13287(RTCW(tr1));
	tr2 = *(EIF_REFERENCE *)(Current);
	F1108_8090(RTCW(Result), tr1, tr2);
	RTLE;
	return Result;
}

void EIF_Minit435 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
